==> typolight-2.6.7.tar.gz: typolight-2.6.7/system/modules/tpl_editor/languages/de/tl_templates.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');

/**
 * TYPOlight webCMS
 * Copyright (C) 2005 Leo Feyer
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, please visit the Free
 * Software Foundation website at http://www.gnu.org/licenses/.
 *
 * PHP version 5
 * @copyright  Leo Feyer 2005
 * @author     Leo Feyer <leo@typolight.org>
 * @package    TemplateEditor
 * @license    LGPL
 * @filesource
 */


/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_templates']['original'] = array('Originalvorlagen', 'Wählen Sie die Originalvorlage aus, die Sie bearbeiten möchten. Es wird eine lokale Kopie im Ordner <em>templates</em> angelegt.');


/**
 * Reference
 */
$GLOBALS['TL_LANG']['tl_templates']['headline'] = 'Eine neues Template erstellen';
$GLOBALS['TL_LANG']['tl_templates']['newTpl']   = 'Template erstellen';
$GLOBALS['TL_LANG']['tl_templates']['exists']   = 'Ein eigenes Template namens "%s" ist bereits vorhanden!';


/**
 * Buttons
 */
$GLOBALS['TL_LANG']['tl_templates']['new']    = array('Neues Template', 'Ein neues Template erstellen');
$GLOBALS['TL_LANG']['tl_templates']['edit']   = array('Template bearbeiten', 'Template "%s" bearbeiten');
$GLOBALS['TL_LANG']['tl_templates']['source'] = array('Quelltext bearbeiten', 'Den Quelltext der Datei "%s" bearbeiten');
$GLOBALS['TL_LANG']['tl_templates']['delete'] = array('Template löschen', 'Template "%s" löschen');

?>

==> typolight-2.7.5.tar.gz: typolight-2.7.5/system/modules/tpl_editor/languages/de/tl_templates.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');

/**
 * TYPOlight webCMS
 * Copyright (C) 2005-2009 Leo Feyer
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, please visit the Free
 * Software Foundation website at http://www.gnu.org/licenses/.
 *
 * PHP version 5
 * @copyright  Leo Feyer 2005-2009
 * @author     Leo Feyer <leo@typolight.org>
 * @package    TemplateEditor
 * @license    LGPL
 * @filesource
 */


/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_templates']['original'] = array('Originaltemplates', 'Eine Kopie des ausgewählten Templates wird im <em>templates</em>-Verzeichnis gespeichert.');


/**
 * Reference
 */
$GLOBALS['TL_LANG']['tl_templates']['headline'] = 'Ein neues Template erstellen';
$GLOBALS['TL_LANG']['tl_templates']['newTpl']   = 'Template erstellen';
$GLOBALS['TL_LANG']['tl_templates']['exists']   = 'Das Template "%s" existiert bereits!';


/**
 * Buttons
 */
$GLOBALS['TL_LANG']['tl_templates']['new']    = array('Neues Template', 'Ein neues Template erstellen');
$GLOBALS['TL_LANG']['tl_templates']['edit']   = array('Template umbenennen', 'Template "%s" umbenennen');
$GLOBALS['TL_LANG']['tl_templates']['source'] = array('Template bearbeiten', 'Template "%s" bearbeiten');
$GLOBALS['TL_LANG']['tl_templates']['delete'] = array('Template löschen', 'Template "%s" löschen');

?>
